@@ -1,17 +1,17 @@
-#' Emissions factors for Environment Company of Sao Paulo, Brazil (CETESB) 2016
+#' Emissions factors for Environment Company of Sao Paulo, Brazil (CETESB) 2017
 #'
 #' \code{\link{ef_cetesb}} returns a vector or data.frame of Brazilian emission factors.
-#' @param p Character; Pollutants: "COd", "HCd", "NMHCd", "CH4", "NOxd", "CO2"
+#' @param p Character; Pollutants: "COd", "HCd", "NMHCd", "CH4", "NOxd", "CO2",
 #' "PM", "N2O", "KML", "FC", "NO2d", "NOd", "gD/KWH", "gCO2/KWH", "RCHOd",
 #' "CO", "HC", "NMHC", "NOx", "NO2" ,"NO", "RCHO" (g/km). The letter 'd' means deteriorated
 #' factor. Also, evaporative emissions at average temperature ranges:
-#' "D_20_35", "S_20_35", "R_20_35", "D_10_25", "S_10_25", "R_10_25", "D_0_15"
+#' "D_20_35", "S_20_35", "R_20_35", "D_10_25", "S_10_25", "R_10_25", "D_0_15",
 #' "S_0_15" and "R_0_15" where D means diurnal (g/day), S hot/warm soak (g/trip)
 #' and R hot/warm running losses (g/trip).
-#' @param veh Character; Vehicle categories: "PC_G", "PC_FG", "PC_FE", "PC_E"
-#' "LCV_G", "LCV_FG", "LCV_FE", "LCV_E", "LCV_D", "SLT", "LT", "MT", "SHT"
-#' "HT", "UB", "SUB", "COACH", "ARTIC", "M_G_150", "M_G_150_500", "M_G_500"
-#' "M_FG_150", "M_FG_150_500", "M_FG_500". "M_FE_150", "M_FE_150_500",
+#' @param veh Character; Vehicle categories: "PC_G", "PC_FG", "PC_FE", "PC_E",
+#' "LCV_G", "LCV_FG", "LCV_FE", "LCV_E", "LCV_D", "SLT", "LT", "MT", "SHT",
+#' "HT", "UB", "SUB", "COACH", "ARTIC", "M_G_150", "M_G_150_500", "M_G_500",
+#' "M_FG_150", "M_FG_150_500", "M_FG_500", "M_FE_150", "M_FE_150_500",
 #' "M_FE_500", "CICLOMOTOR", "GNV"
 #' @param year Numeric; Filter the emission factor to start from a specific base year.
 #' @param full Logical; To return a data.frame instead or a vector adding
@@ -35,10 +35,11 @@
 #' @examples {
 #' a <- ef_cetesb("CO", "PC_G")
 #' b <- ef_cetesb("R_10_25", "PC_G")
+#' c <- ef_cetesb("CO", c("PC_G", "PC_FE"))
 #' }
-ef_cetesb <- function(p, veh, year = 2016, full = FALSE){
+ef_cetesb <- function(p, veh, year = 2017, full = FALSE){
   ef <- sysdata$cetesb
-  ef <-  ef[ef$Age <= 50, ]
+  ef <-  ef[ef$Age <= 40, ]
   ef <- ef[ef$Year <= year, ]
   evapd <- c("D_20_35","D_10_25","D_0_15")
   evap <- c("S_20_35", "R_20_35", "S_10_25", "R_10_25", "S_0_15", "R_0_15")
@@ -53,7 +54,7 @@ ef_cetesb <- function(p, veh, year = 2016, full = FALSE){
     cat("Units: [g/trip]\n")
   }
   nveh <- names(ef)[12:ncol(ef)]
-  if(!veh %in% nveh){
+  if(any(!veh %in% nveh)){
     stop(paste("Please, choose on of the following categories:", nveh))
   }
   if(full) {
